Package: BiocHail
Date: 2025-06-30
Title: basilisk and hail
Version: 1.12.0
Authors@R: 
    c(person(
        "Vincent", "Carey", role = c("aut", "cre"),
        email = "stvjc@channing.harvard.edu",
        comment = c(ORCID = "0000-0003-4046-0063")
     )
    )
Description: Use hail via basilisk when appropriate, or via reticulate.
	This package can be used in terra.bio to interact with UK Biobank
	resources processed by hail.is.
License: Artistic-2.0
Encoding: UTF-8
Depends: R (>= 4.3.0), graphics, stats, utils
Imports: reticulate, basilisk, BiocFileCache, methods, dplyr,
        BiocGenerics
Suggests: knitr, testthat, BiocStyle, ggplot2, DT
VignetteBuilder: knitr
biocViews: Infrastructure
RoxygenNote: 7.3.2
URL: https://github.com/vjcitn/BiocHail
BugReports: https://github.com/vjcitn/BiocHail/issues
git_url: https://git.bioconductor.org/packages/BiocHail
git_branch: RELEASE_3_23
git_last_commit: fcd2afe
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-29
NeedsCompilation: no
Packaged: 2026-04-29 20:39:32 UTC; biocbuild
Author: Vincent Carey [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4046-0063>)
Maintainer: Vincent Carey <stvjc@channing.harvard.edu>
