# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,hail.table.Table)
S3method(filter,hail.table.Table)
S3method(get_key,hail.table.Table)
export(as.data.frame)
export(bare_hail)
export(filter)
export(get_1kg)
export(get_key)
export(get_ukbb_sumstat_10kloci_mt)
export(hail_init)
export(hail_init_simple)
export(hail_stop)
export(multipop_df)
export(osn_1kg_path)
export(osn_ukbb_sumst10k_path)
export(path_1kg_annotations)
export(rg_update)
export(ukbb_init)
exportMethods(colnames)
exportMethods(rownames)
import(BiocFileCache)
import(basilisk)
import(methods)
import(utils)
importFrom(BiocGenerics,as.data.frame)
importFrom(BiocGenerics,colnames)
importFrom(BiocGenerics,rownames)
importFrom(dplyr,filter)
importFrom(reticulate,import)
