# BiocHail

This is a multi-step overview of Hail for genetic association
studies

## Tutorial overview

The basic layout, following the [Hail GWAS tutorial](https://hail.is/docs/0.2/tutorials/01-genome-wide-association-study.html):

![topics](https://github.com/vjcitn/BiocHail/raw/main/toc1.png)

We'll see how to use a very small excerpt from the
1000 genomes study to produce

![litman](https://github.com/vjcitn/BiocHail/raw/main/litman.png)

Along the way, we illustrate and adjust for population stratification:

![popstrat](https://github.com/vjcitn/BiocHail/raw/main/popstrat.png)

## Larger data problem -- 1000 genomes data with T2T reference

We have arranged a serialization of genotypes on chromosome 17
for 3202 1000 genomes samples.

## Relevant LD resources ... in which cloud?

Still to come.

## Simulating multipopulation genotype surveys

Still to come.

## Binding phenotypes from FHIR to Hail

Still to come.
