#' HWE-normalized PCA scores for 3202 thousand-genomes samples genotyped with the
#' telomere-to-telomere reference
#' @note The genotypes are from a 1% sample of loci on chr17
#' @docType data
#' @usage data("pcs_38k")
#' @return data.frame
#' @examples
#' data(pcs_38k)
#' dim(pcs_38k)
#' @format data.frame
"pcs_38k"

#' HWE-normalized PCA scores for 3202 thousand-genomes samples genotyped with the
#' telomere-to-telomere reference
#' @note The genotypes are from a 5% sample of loci on chr17
#' @docType data
#' @usage data("pcs_191k")
#' @return data.frame
#' @examples
#' data(pcs_191k)
#' dim(pcs_191k)
#' @format data.frame
"pcs_191k"

#' data.frame with metadata about 3202 samples genotyped against T2T reference
#' @note Source: index files described at `https://www.internationalgenome.org/data-portal/data-collection/30x-grch38`
#' @docType data
#' @usage data("kg_3202")
#' @return data.frame
#' @examples
#' data(kg_3202)
#' dim(kg_3202)
#' @format data.frame
"kg_3202"
